@@ -42,7 +42,10 @@ def check_output(*args, **kwargs):
         cmd = kwargs.get("args")
         if cmd is None:
             cmd = args[0]
-        raise CalledProcessError(retcode, cmd, output=output)
+        if sys.version_info < (2,7) and sys.platform == "win32":
+            raise CalledProcessError(retcode, cmd)
+        else:
+            raise CalledProcessError(retcode, cmd, output=output)
     return output
 
 class Hub:
@@ -323,7 +326,7 @@ def getbasebaser(prog):
 def add_generic_options(parser):
     group = parser.add_argument_group("generic options")
     group.add_argument("--version", action="version",
-                       version="devpi-server-" + __version__)
+                       version=devpi.__version__)
     group.add_argument("--debug", action="store_true",
         help="show debug messages including more info on server requests")
     group.add_argument("-y", action="store_true", dest="yes",
